============================================
``psyclone.domain.lfric.kern_stub_arg_list``
============================================

.. automodule:: psyclone.domain.lfric.kern_stub_arg_list

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.kern_stub_arg_list


Classes
=======

- :py:class:`KernStubArgList`:
  Creates the argument list required to create and declare the


.. autoclass:: KernStubArgList
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: KernStubArgList
      :parts: 1
